# ListCatalogueEntriesResponse

Response object for a list of catalogue entries
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**catalogue_entries** | [**list[CatalogueEntry]**](CatalogueEntry.md) | List of catalogue entries | [optional] [readonly] 
**limit** | **int** | Limit the number of catalogue entries included in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


